# Synopsis
**RNAscClust** is a pipeline designed to cluster a set of paralogous noncoding RNA (ncRNA) sequences based on 
conserved secondary structure. The input to RNAscClust is a set of multiple sequence alignments, each containing 
a paralog sequence to be clustered that is aligned to a set of orthologous sequences. The aim of RNAscClust is 
to aid the discovery of families and classes of ncRNAs.

# Directory contents

This project is organized in several subdirectories whose content is
described below.

**Note:** As a general rule, everything should be placed under version control.
However, static files in data/ and results/ and compiled binaries do form an exception to this rule. They are fetched from our servers using some synchronization scripts described below.

**Note:** Compress files whenever possible.

### Config/
Configuration files to set the pipeline paramaters and specify path to the dependencies. Includes default config file and samples to override the default values with custom ones.

### doc/
Documentation of programs in src/ and bin/ is stored here.


### bin/
Contains scripts/binaries which do not need to be compiled.

### lib/
Required Perl libraries.

### data/
Contains input data sets.
Subfolders are named according to their creation date in YYYYMMDD format (e.g. data/20140101-Initial-Data/)
and contain a README describing who added the data and how it was obtained.

These data sets are **not** stored in this git repository but on demand synced to
a local, checked-out version of the repository by invoking the script sync-data.sh

### results/
Tracks the results of computational experiments performed on the data.
These results are **not** stored in this git repository but on demand synced to
a local, checked-out version of the repository by invoking the script sync-results.sh
Each experiment is stored in a separate subfolder named according to its creation date,
e.g.: results/YYYYMMDD-First-Clustering/
This subfolder contains a documented driver script generating the experimental results
and a script analyzing these results, if needed.
**Note:** In contrast to the result data, these driver and analysis scripts should be
put under version control.

# Installation
Having the tools mentioned below installed and configured is a necessary step for running the pipeline.
## Dependencies

- Generic tools and libs: 
   ```Python-2, Biopython, NumPy, scikit-learn, Perl, GNU R, bzip2, GNU time, matplotlib.```

   Under a Debian or Ubuntu system, installing the following debian/ubuntu packages should satisfy these dependencies: 
<code>python python-biopython  scikit-learn r-base-core bzip2 time python-numpy python-numpy-dev python-scipy libatlas-dev python-matplotlib</code>

- EDeN: RNAscClust contains a precompiled version of EDeN, the SVM package used for feature creation and classification. This binary should run on most Linux-based systems. In case it does not run on your system, please call <code>bash ./recompile_EDeN.sh</code> from the GraphProt main directory.
- Vienna RNA 2 
- PETFold 2.0
- LocARNA 
- Infernal 1.0.2 
- CMfinder 


For installation instruction of each dependency please refer to its manual. If you had problems on downloading, installing or configuring these tools please contact us.
Alternatively it may be possible to use the pre-compiled binaries available on our server, these binaries should run on most Linux-based platforms:
#### <a name="binaries"></a> Pre-compiled binary set for Linux systems
The complete set of pre-compiled non-generic binaries for Linux platforms:

[ftp://biftp.informatik.uni-freiburg.de/pub/RNAscClust/tools-binaries.tar.gz](ftp://biftp.informatik.uni-freiburg.de/pub/RNAscClust/tools-binaries.tar.gz)

## Configuration
The file under `Config/default.config` should be configured according to the installed dependencies paths. 
The file  `Config/default.config` is always loaded while invoking the RNAscClust pipeline. However an additional custom config file can be passed as an argument to the pipeline. 
Variable names set by custom file must have be already defined in default configuration and needs not to cover all those.
However the custom values will override the default values. Please see `docker-sge.config` as an example.

Please note that paths in the default configuration match to the directory structure of the tarball for pre-compiled [binaries](#binaries), therefor in the case of precompiled binaries, 
minimal configuration efforts would be expected.

### SGE Grid support
RNAscClust pipeline can run under a SGE grid computing computer cluster system. In this case variables prefixed "SGE_" should be set according to the host system settings.


# Usage
The python script bin/run_rnascclust.py runs the RNAscClust pipeline for an input directory of alignments to be clustered.

``` 
usage: run_rnascclust.py [-h] --alignments-dir ALIGNMENTS_DIR --result-path
                         RESULT_PATH [--local-config LOCAL_CONFIG]
                         [--sge-parallel] [--rep-fasta REP_FASTA]
                         [--temp-path TEMP_PATH] [--structure-is-given]
                         [--predict-structure] [--keep-temp]
                         [--min-class-size MIN_CLASS_SIZE] [--debug]

optional arguments:
  -h, --help            show this help message and exit
  --alignments-dir ALIGNMENTS_DIR, -i ALIGNMENTS_DIR
                        Path to the directory containing stockholm files
  --result-path RESULT_PATH
                        Path to creat output directory RESULTS_AC/ under it
                        stores intermediate and final results
  --local-config LOCAL_CONFIG
                        if a local configuration is to be used, path to the
                        local configuration file
  --sge-parallel        Run in parallel multicore/SGE mode
  --rep-fasta REP_FASTA
                        A fasta file containing one representative sequence
                        from each alignment under the input-directory.
                        Representative could be e.g. the human sequence of
                        each alignment
  --temp-path TEMP_PATH
                        Path to store intermediate temporary direcotry named
                        TEMP_AC
  --structure-is-given  Do not use PETfold to predict the secondary consensus
                        " structure of each alignment
  --predict-structure   Use PETfold to predict the secondary consensus
                        structure of each alignment
  --keep-temp, -k       Keep files after run finished
  --min-class-size MIN_CLASS_SIZE
                        Discard families where number of subalignments is less
                        than min
  --debug, -d           Debug mode, verbose information logged
```

Example:

```python2 $(INSTALLATION_DIRECTORY)/bin/run_rnascclust.py --alignments-dir data/cliques-low/alignments/ --rep-fasta data/cliques-low/representatives/representatives.fa --predict-structure  --result-path . --local-config Config/docker-sge.config --sge'```

## Contact
For questions, please contact us:

- Milad Miladi <miladim@informatik.uni-freiburg.de>
- Alexander Junge <ajunge@rth.dk>

